@@ -1,5 +1,5 @@
 --
--- lua-MessagePack : <http://fperrad.github.io/lua-MessagePack/>
+-- lua-MessagePack : <https://fperrad.frama.io/lua-MessagePack/>
 --
 
 local assert = assert
@@ -346,7 +346,7 @@ local function unpack_cursor (c)
         c:underflow(i)
         s, i, j = c.s, c.i, c.j
     end
-    local val = s:sub(i, i):byte()
+    local val = s:byte(i)
     c.i = i+1
     return unpackers[val](c, val)
 end
@@ -638,9 +638,9 @@ else
 end
 set_array'without_hole'
 
-m._VERSION = '0.5.1'
+m._VERSION = '0.5.2'
 m._DESCRIPTION = "lua-MessagePack : a pure Lua 5.3 implementation"
-m._COPYRIGHT = "Copyright (c) 2012-2018 Francois Perrad"
+m._COPYRIGHT = "Copyright (c) 2012-2019 Francois Perrad"
 return m
 --
 -- This library is licensed under the terms of the MIT/X11 license,
